@@ -309,16 +309,34 @@ cd_cache_check_archive (CdCache *cache,
     }
     archive_read_data_skip(a);
   }
-  r = archive_read_finish(a);
-  if (r != ARCHIVE_OK) {
-    g_set_error (error, TOTEM_PL_PARSER_ERROR, TOTEM_PL_PARSER_ERROR_MOUNT_FAILED,
-		 _("Failed to mount %s."), filename);
-    return FALSE;
-  }
+  archive_read_finish(a);
   return TRUE;
 #endif
 }
 
+static char *
+unescape_archive_name (const char *orig_uri)
+{
+  char *uri;
+  guint len;
+  char *escape1, *escape2;
+
+  uri = g_strdup (orig_uri);
+
+  /* Remove trailing slash */
+  len = strlen (uri);
+  if (uri[len - 1] == '/')
+    uri[len - 1] = '\0';
+
+  /* Unescape the path */
+  escape1 = g_uri_unescape_string (uri + strlen ("archive://"), NULL);
+  escape2 = g_uri_unescape_string (escape1, NULL);
+  g_free (escape1);
+  g_free (uri);
+
+  return escape2;
+}
+
 static CdCache *
 cd_cache_new (const char *dev,
 	      GError     **error)
@@ -334,8 +352,16 @@ cd_cache_new (const char *dev,
     local = g_strdup (dev);
     file = g_file_new_for_path (dev);
   } else {
-    file = g_file_new_for_commandline_arg (dev);
-    local = g_file_get_path (file);
+    if (g_str_has_prefix (dev, "archive://")) {
+      char *orig_uri;
+      orig_uri = unescape_archive_name (dev);
+      file = g_file_new_for_uri (orig_uri);
+      g_free (orig_uri);
+      local = g_file_get_path (file);
+    } else {
+      file = g_file_new_for_commandline_arg (dev);
+      local = g_file_get_path (file);
+    }
   }
 
   if (local == NULL) {
@@ -710,7 +736,7 @@ totem_cd_detect_type_from_dir (const char *dir, char **mrl, GError **error)
   }
 
   if (type == MEDIA_TYPE_DVD) {
-    *mrl = totem_cd_mrl_from_type ("dvd", cache->mountpoint);
+    *mrl = totem_cd_mrl_from_type ("dvd", cache->mountpoint ? cache->mountpoint : cache->device);
   } else if (type == MEDIA_TYPE_VCD) {
     *mrl = totem_cd_mrl_from_type ("vcd", cache->mountpoint);
   }
