@@ -1271,6 +1271,7 @@ totem_pl_parser_init (TotemPlParser *parser)
 {
 	parser->priv = G_TYPE_INSTANCE_GET_PRIVATE (parser, TOTEM_TYPE_PL_PARSER, TotemPlParserPrivate);
 	parser->priv->main_thread = g_thread_self ();
+	g_mutex_init (&parser->priv->ignore_mutex);
 }
 
 static void
@@ -2383,8 +2384,7 @@ totem_pl_parser_mime_type_from_data (gconstpointer data, int len)
  * @len: the length of data to check
  * @debug: %TRUE if debug statements should be printed
  *
- * Checks if the first @len bytes of @data can be parsed, using the same checks
- * and precedences as totem_pl_parser_ignore().
+ * Checks if the first @len bytes of @data can be parsed.
  *
  * Return value: %TRUE if @data can be parsed
  **/
